@@ -23,6 +23,7 @@
 #define __CPUFREQ_MONITOR_PROCFS_H__
 
 #include <glib-object.h>
+
 #include "cpufreq-monitor.h"
 
 #define TYPE_CPUFREQ_MONITOR_PROCFS            (cpufreq_monitor_procfs_get_type ())
@@ -43,7 +44,7 @@ struct _CPUFreqMonitorProcfsClass {
 	   CPUFreqMonitorClass parent_class;
 };
 
-GType           cpufreq_monitor_procfs_get_type ();
+GType           cpufreq_monitor_procfs_get_type (void) G_GNUC_CONST;
 CPUFreqMonitor *cpufreq_monitor_procfs_new      (guint cpu);
 
 #endif /* __CPUFREQ_MONITOR_PROCFS_H__ */
